==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/sites/lang/sites_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=eo
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'Abonligo malsukcesis : la indikata abondosiero (backend-dosiero) ne estas deĉifrebla aŭ proponas neniun artikolon.',
	'avis_echec_syndication_02' => 'Abonligo malsukcesis : ne eblas aliri abondosieron (backend-dosiero) de tiu retejo.',
	'avis_site_introuvable' => 'Netrovebla retejo',
	'avis_site_syndique_probleme' => 'Atentu, okazis problemo pri abonrilato de tiu ĉi retejo ; la sistemo estas portempe ĉesigita. Kontrolu la retadreson de la abondosiero de tiu ĉi retejo (@url_syndic@), kaj provu novan reakiron de la informoj.',
	'avis_sites_probleme_syndication' => 'Okazis problemo pri abonrilato inter tiuj retejoj',
	'avis_sites_syndiques_probleme' => 'Tiuj abonligitaj retejoj okazigis problemon',

	// B
	'bouton_radio_modere_posteriori' => 'aposteriore moderigata', # MODIF
	'bouton_radio_modere_priori' => 'apriore moderigata', # MODIF
	'bouton_radio_non_syndication' => 'Neniu abonrilato',
	'bouton_radio_syndication' => 'Abonrilato :',

	// E
	'entree_adresse_fichier_syndication' => 'Retadreso de la abondosiero :',
	'entree_adresse_site' => '<b>Adreso de la retejo</b> [Deviga]',
	'entree_description_site' => 'Priskribo de la retejo',

	// F
	'form_prop_nom_site' => 'Nomo de la retejo',

	// I
	'icone_modifier_site' => 'Modifi tiun ĉi retejon',
	'icone_referencer_nouveau_site' => 'Referencigi novan retejon',
	'icone_voir_sites_references' => 'Vidi la referencigitajn retejojn',
	'info_a_valider' => '[validigenda]',
	'info_bloquer' => 'bloki',
	'info_bloquer_lien' => 'bloki tiun ligilon',
	'info_derniere_syndication' => 'La lasta abonĝisdatigo de tiu retejo estis farita la ',
	'info_liens_syndiques_1' => 'abonligiloj',
	'info_liens_syndiques_2' => 'estas validigotaj.',
	'info_nom_site_2' => '<b>Nomo de la retejo</b> [Deviga]',
	'info_panne_site_syndique' => 'Abonligita retejo paneas',
	'info_probleme_grave' => 'problemo de',
	'info_question_proposer_site' => 'Kiu povas proponi referencigitajn retejojn ?',
	'info_retablir_lien' => 'Restaŭri tiun ligilon',
	'info_site_attente' => 'Retejo atendanta validigon',
	'info_site_propose' => 'Retejo proponita la :',
	'info_site_reference' => 'Retejo rete referencigita',
	'info_site_refuse' => 'Rifuzita retejo',
	'info_site_syndique' => 'Tiu ĉi retejo estas abonligita...', # MODIF
	'info_site_valider' => 'Validigotaj retejoj',
	'info_sites_referencer' => 'Referencigi retejon',
	'info_sites_refuses' => 'La rifuzitaj retejoj',
	'info_statut_site_1' => 'Tiu retejo estas :',
	'info_statut_site_2' => 'Publikigita',
	'info_statut_site_3' => 'Proponita',
	'info_statut_site_4' => 'En rubujo', # MODIF
	'info_syndication' => 'abonrilato :',
	'info_syndication_articles' => 'artikolo(j)',
	'item_bloquer_liens_syndiques' => 'Bloki la abonligilojn por validigo',
	'item_gerer_annuaire_site_web' => 'Mastrumi retej-adresaron',
	'item_non_bloquer_liens_syndiques' => 'Ne bloki la ligilojn naskitajn de abonrilato',
	'item_non_gerer_annuaire_site_web' => 'Malaktivigi la retej-adresaron',
	'item_non_utiliser_syndication' => 'Ne uzi la aŭtomatan abonrilaton',
	'item_utiliser_syndication' => 'Uzi la aŭtomatan abonrilaton',

	// L
	'lien_mise_a_jour_syndication' => 'Ĝisdatigi nun',
	'lien_nouvelle_recuperation' => 'Provi novan reakiron de la datenoj',

	// S
	'syndic_choix_moderation' => 'Kion fari el la ligiloj venontaj el tiu retejo ?',
	'syndic_choix_oublier' => 'Kion fari el la ligiloj, kiuj ne plu aperas en la abondosiero ?',
	'syndic_choix_resume' => 'Iuj retejoj disponigas la tutan tekston de la artikoloj. Kiam tiu ĉi disponeblas, ĉu vi deziras abonligi :',
	'syndic_lien_obsolete' => 'eks-uzita ligilo',
	'syndic_option_miroir' => 'aŭtomate bloki ilin',
	'syndic_option_oubli' => 'forviŝi ilin (post @mois@ monatoj)',
	'syndic_option_resume_non' => 'la kompleta enhavo de la artikoloj (HTML-formate)',
	'syndic_option_resume_oui' => 'simpla resumo (tekt-formate)',
	'syndic_options' => 'Abon-agordoj :',

	// T
	'texte_liens_sites_syndiques' => 'Abonligoj povas
   esti blokataj apriore ; la ĉi-suba agordo
   indikas la defaŭltan agordon de la
   abonligitaj retejoj je ties kreo. Poste
   eblas ĉiukaze malbloki ĉiun
   ligilon unuope, aŭ elekti, retejon post retejo, bloki estigotajn
ligilojn al jena aŭ alia retejo.', # MODIF
	'texte_messages_publics' => 'Publikaj mesaĝoj de la artikolo :',
	'texte_non_fonction_referencement' => 'Vi povas preferi ne uzi tiun aŭtomatan funkcion kaj indiki mem la elementojn koncernantajn tiun ĉi retejon...', # MODIF
	'texte_referencement_automatique' => '<b>Aŭtomata retej-referenciga procezo</b><br />Vi povas rapide referencigi retejon indikante ĉi-sube la deziratan retadreson aŭ ties abonligon. SPIP aŭtomate abonŝutos la informojn kiuj koncernas tiun retejon (titolon, priskribon...).', # MODIF
	'texte_syndication' => 'Eblas elpreni aŭtomate la liston de novaĵoj de iu retejo,
  se tiu retejo tion permesas. Por tio, vi devas aktivigi la abonrilaton.
  <blockquote><i>Iuj retgastigantoj malaktivigas tiun funkcion ;
  tiukaze vi ne povas abonligi la enhavon
  ekde via retejo.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Artikoloj abonŝutitaj el tiu retejo',
	'titre_dernier_article_syndique' => 'Laste abonŝutitaj artikoloj',
	'titre_page_sites_tous' => 'La referencigitaj retejoj',
	'titre_referencement_sites' => 'Referencigado de retejoj kaj abonrilato',
	'titre_site_numero' => 'RETEJO NUMERO :',
	'titre_sites_proposes' => 'La proponitaj retejoj',
	'titre_sites_references_rubrique' => 'La retejoj referencigitaj en tiu ĉi rubriko',
	'titre_sites_syndiques' => 'La abonligitaj retejoj',
	'titre_sites_tous' => 'La referencigitaj retejoj',
	'titre_syndication' => 'Reteja abonligo'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/sites/lang/sites_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=eo
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'Abonligo malsukcesis : la indikata abondosiero (backend-dosiero) ne estas deĉifrebla aŭ proponas neniun artikolon.',
	'avis_echec_syndication_02' => 'Abonligo malsukcesis : ne eblas aliri abondosieron (backend-dosiero) de tiu retejo.',
	'avis_site_introuvable' => 'Netrovebla retejo',
	'avis_site_syndique_probleme' => 'Atentu, okazis problemo pri abonrilato de tiu ĉi retejo ; la sistemo estas portempe ĉesigita. Kontrolu la retadreson de la abondosiero de tiu ĉi retejo (@url_syndic@), kaj provu novan reakiron de la informoj.',
	'avis_sites_probleme_syndication' => 'Okazis problemo pri abonrilato inter tiuj retejoj',
	'avis_sites_syndiques_probleme' => 'Tiuj abonligitaj retejoj okazigis problemon',

	// B
	'bouton_radio_modere_posteriori' => 'aposteriore moderigata', # MODIF
	'bouton_radio_modere_priori' => 'apriore moderigata', # MODIF
	'bouton_radio_non_syndication' => 'Neniu abonrilato',
	'bouton_radio_syndication' => 'Abonrilato :',

	// E
	'entree_adresse_fichier_syndication' => 'Retadreso de la abondosiero :',
	'entree_adresse_site' => '<b>Adreso de la retejo</b> [Deviga]',
	'entree_description_site' => 'Priskribo de la retejo',

	// F
	'form_prop_nom_site' => 'Nomo de la retejo',

	// I
	'icone_modifier_site' => 'Modifi tiun ĉi retejon',
	'icone_referencer_nouveau_site' => 'Referencigi novan retejon',
	'icone_voir_sites_references' => 'Vidi la referencigitajn retejojn',
	'info_1_article_syndique' => '1 abonligita artikolo',
	'info_1_site' => '1 retejo',
	'info_a_valider' => '[validigenda]',
	'info_aucun_article_syndique' => 'Neniu abonligita artikolo',
	'info_aucun_site' => 'Neniu retejo',
	'info_bloquer' => 'bloki',
	'info_bloquer_lien' => 'bloki tiun ligilon',
	'info_derniere_syndication' => 'La lasta abonĝisdatigo de tiu retejo estis farita la ',
	'info_liens_syndiques_1' => 'abonligiloj',
	'info_liens_syndiques_2' => 'estas validigotaj.',
	'info_nb_articles_syndiques' => '@nb@ abonligitaj artikoloj',
	'info_nb_sites' => '@nb@ retejoj',
	'info_nom_site_2' => '<b>Nomo de la retejo</b> [Deviga]',
	'info_panne_site_syndique' => 'Abonligita retejo paneas',
	'info_probleme_grave' => 'problemo de',
	'info_question_proposer_site' => 'Kiu povas proponi referencigitajn retejojn ?',
	'info_retablir_lien' => 'Restaŭri tiun ligilon',
	'info_site_attente' => 'Retejo atendanta validigon',
	'info_site_propose' => 'Retejo proponita la :',
	'info_site_reference' => 'Retejo rete referencigita',
	'info_site_refuse' => 'Rifuzita retejo',
	'info_site_syndique' => 'Tiu ĉi retejo estas abonligita...', # MODIF
	'info_site_valider' => 'Validigotaj retejoj',
	'info_sites_referencer' => 'Referencigi retejon',
	'info_sites_refuses' => 'La rifuzitaj retejoj',
	'info_statut_site_1' => 'Tiu retejo estas :',
	'info_statut_site_2' => 'Publikigita',
	'info_statut_site_3' => 'Proponita',
	'info_statut_site_4' => 'En rubujo', # MODIF
	'info_syndication' => 'abonrilato :',
	'info_syndication_articles' => 'artikolo(j)',
	'item_bloquer_liens_syndiques' => 'Bloki la abonligilojn por validigo',
	'item_gerer_annuaire_site_web' => 'Mastrumi retej-adresaron',
	'item_non_bloquer_liens_syndiques' => 'Ne bloki la ligilojn naskitajn de abonrilato',
	'item_non_gerer_annuaire_site_web' => 'Malaktivigi la retej-adresaron',
	'item_non_utiliser_syndication' => 'Ne uzi la aŭtomatan abonrilaton',
	'item_utiliser_syndication' => 'Uzi la aŭtomatan abonrilaton',

	// L
	'lien_mise_a_jour_syndication' => 'Ĝisdatigi nun',
	'lien_nouvelle_recuperation' => 'Provi novan reakiron de la datenoj',

	// S
	'syndic_choix_moderation' => 'Kion fari el la ligiloj venontaj el tiu retejo ?',
	'syndic_choix_oublier' => 'Kion fari el la ligiloj, kiuj ne plu aperas en la abondosiero ?',
	'syndic_choix_resume' => 'Iuj retejoj disponigas la tutan tekston de la artikoloj. Kiam tiu ĉi disponeblas, ĉu vi deziras abonligi :',
	'syndic_lien_obsolete' => 'eks-uzita ligilo',
	'syndic_option_miroir' => 'aŭtomate bloki ilin',
	'syndic_option_oubli' => 'forviŝi ilin (post @mois@ monatoj)',
	'syndic_option_resume_non' => 'la kompleta enhavo de la artikoloj (HTML-formate)',
	'syndic_option_resume_oui' => 'simpla resumo (tekt-formate)',
	'syndic_options' => 'Abon-agordoj :',

	// T
	'texte_liens_sites_syndiques' => 'Abonligoj povas
   esti blokataj apriore ; la ĉi-suba agordo
   indikas la defaŭltan agordon de la
   abonligitaj retejoj je ties kreo. Poste
   eblas ĉiukaze malbloki ĉiun
   ligilon unuope, aŭ elekti, retejon post retejo, bloki estigotajn
ligilojn al jena aŭ alia retejo.', # MODIF
	'texte_messages_publics' => 'Publikaj mesaĝoj de la artikolo :',
	'texte_non_fonction_referencement' => 'Vi povas preferi ne uzi tiun aŭtomatan funkcion kaj indiki mem la elementojn koncernantajn tiun ĉi retejon...', # MODIF
	'texte_referencement_automatique' => '<b>Aŭtomata retej-referenciga procezo</b><br />Vi povas rapide referencigi retejon indikante ĉi-sube la deziratan retadreson aŭ ties abonligon. SPIP aŭtomate abonŝutos la informojn kiuj koncernas tiun retejon (titolon, priskribon...).', # MODIF
	'texte_syndication' => 'Eblas elpreni aŭtomate la liston de novaĵoj de iu retejo,
  se tiu retejo tion permesas. Por tio, vi devas aktivigi la abonrilaton.
  <blockquote><i>Iuj retgastigantoj malaktivigas tiun funkcion ;
  tiukaze vi ne povas abonligi la enhavon
  ekde via retejo.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Artikoloj abonŝutitaj el tiu retejo',
	'titre_dernier_article_syndique' => 'Laste abonŝutitaj artikoloj',
	'titre_page_sites_tous' => 'La referencigitaj retejoj',
	'titre_referencement_sites' => 'Referencigado de retejoj kaj abonrilato',
	'titre_site_numero' => 'RETEJO NUMERO :',
	'titre_sites_proposes' => 'La proponitaj retejoj',
	'titre_sites_references_rubrique' => 'La retejoj referencigitaj en tiu ĉi rubriko',
	'titre_sites_syndiques' => 'La abonligitaj retejoj',
	'titre_sites_tous' => 'La referencigitaj retejoj',
	'titre_syndication' => 'Reteja abonligo'
);

?>
